Module dyn_debug

Module dyn_debug 

Structs

DynamicDebugOps

Functions

dynamic_debug_init
Initialize dynamic debug subsystem. This should be called after static keys are initialized, and before any dynamic debug site is hit.