pub struct KernelKprobeOps;Trait Implementations
Sourceimpl Debug for KernelKprobeOps
impl Debug for KernelKprobeOps
Sourceimpl KprobeAuxiliaryOps for KernelKprobeOps
impl KprobeAuxiliaryOps for KernelKprobeOps
Sourcefn copy_memory(src: *const u8, dst: *mut u8, len: usize, user_pid: Option<i32>)
fn copy_memory(src: *const u8, dst: *mut u8, len: usize, user_pid: Option<i32>)
Copy memory from source to destination. If
user_pid is Some(pid), it indicates that the src is in user space.
The dst is always in kernel space.Sourcefn set_writeable_for_address<F: FnOnce(*mut u8)>(
address: usize,
len: usize,
user_pid: Option<i32>,
action: F,
)
fn set_writeable_for_address<F: FnOnce(*mut u8)>( address: usize, len: usize, user_pid: Option<i32>, action: F, )
Enable or disable write permission for the specified address.
Sourcefn alloc_kernel_exec_memory() -> *mut u8
fn alloc_kernel_exec_memory() -> *mut u8
Allocate executable memory(one page)
Sourcefn free_kernel_exec_memory(ptr: *mut u8)
fn free_kernel_exec_memory(ptr: *mut u8)
Deallocate executable memory(one page)
Sourcefn alloc_user_exec_memory<F: FnOnce(*mut u8)>(
pid: Option<i32>,
action: F,
) -> *mut u8
fn alloc_user_exec_memory<F: FnOnce(*mut u8)>( pid: Option<i32>, action: F, ) -> *mut u8
Allocate user executable memory(one page)
Sourcefn free_user_exec_memory(pid: Option<i32>, ptr: *mut u8)
fn free_user_exec_memory(pid: Option<i32>, ptr: *mut u8)
Deallocate user executable memory(one page)
Sourcefn insert_kretprobe_instance_to_task(instance: RetprobeInstance)
fn insert_kretprobe_instance_to_task(instance: RetprobeInstance)
Insert a kretprobe instance to the current task
Sourcefn pop_kretprobe_instance_from_task() -> RetprobeInstance
fn pop_kretprobe_instance_from_task() -> RetprobeInstance
Pop a kretprobe instance from the current task