pub type KprobeAuxiliary = KernelKprobeOps;Expand description
The KprobeAuxiliaryOps impl, aliased under the name the perf module uses.
Aliased Type
pub struct KprobeAuxiliary;pub type KprobeAuxiliary = KernelKprobeOps;The KprobeAuxiliaryOps impl, aliased under the name the perf module uses.
pub struct KprobeAuxiliary;