pub struct ActivationLease { /* private fields */ }Expand description
A per-CPU activation. The scheduler owns the value and must consume/drop it only after installing another root or the kernel root.
Implementations
Sourceimpl ActivationLease
impl ActivationLease
pub fn installed(&self) -> InstalledPageTableRoot
pub const fn cpu(&self) -> usize
Sourcepub fn release_after_kernel_switch(self)
pub fn release_after_kernel_switch(self)
Consumes the lease after an offline path has installed the kernel root and completed its local full TLB flush.