MmPin

Struct MmPin 

pub struct MmPin(/* private fields */);
Short-lived kernel ownership. It is safe to drop in IRQ context because only counters and preallocated queue links are touched; actual page-table destruction belongs to the sleepable reclaimer.

Implementations

Source

impl MmPin

pub fn id(&self) -> AddressSpaceId

pub fn transparent_huge_page_mode(&self) -> TransparentHugePageMode

Returns the process policy attached to the pinned MM identity.

pub fn set_transparent_huge_page_mode(&self, mode: TransparentHugePageMode)

Changes the process-wide THP policy while excluding concurrent faults.

pub fn handle_page_fault_result( &self, vaddr: VirtAddr, access_flags: PageFaultFlags, ) -> FaultResult

Resolves a fault under the MM’s process-wide THP policy.

pub fn handle_page_fault( &self, vaddr: VirtAddr, access_flags: PageFaultFlags, ) -> bool

Resolves a fault for a kernel faultable user-copy scope.

Methods from Deref<Target = Mutex<AddrSpace>>

pub unsafe fn make_guard_unchecked(&self) -> MutexGuard<'_, R, T>

Creates a new MutexGuard without checking if the mutex is locked.

Safety

This method must only be called if the thread logically holds the lock.

Calling this function when a guard has already been produced is undefined behaviour unless the guard was forgotten with mem::forget.

pub fn lock(&self) -> MutexGuard<'_, R, T>

Acquires a mutex, blocking the current thread until it is able to do so.

This function will block the local thread until it is available to acquire the mutex. Upon returning, the thread is the only thread with the mutex held. An RAII guard is returned to allow scoped unlock of the lock. When the guard goes out of scope, the mutex will be unlocked.

Attempts to lock a mutex in the thread which already holds the lock will result in a deadlock.

pub fn try_lock(&self) -> Option<MutexGuard<'_, R, T>>

Attempts to acquire this lock.

If the lock could not be acquired at this time, then None is returned. Otherwise, an RAII guard is returned. The lock will be unlocked when the guard is dropped.

This function does not block.

pub fn is_locked(&self) -> bool

Checks whether the mutex is currently locked.

pub unsafe fn force_unlock(&self)

Forcibly unlocks the mutex.

This is useful when combined with mem::forget to hold a lock without the need to maintain a MutexGuard object alive, for example when dealing with FFI.

Safety

This method must only be called if the current thread logically owns a MutexGuard but that guard has been discarded using mem::forget. Behavior is undefined if a mutex is unlocked when not locked.

pub unsafe fn raw(&self) -> &R

Returns the underlying raw mutex object.

Note that you will most likely need to import the RawMutex trait from lock_api to be able to call functions on the raw mutex.

Safety

This method is unsafe because it allows unlocking a mutex while still holding a reference to a MutexGuard.

pub fn data_ptr(&self) -> *mut T

Returns a raw pointer to the underlying data.

This is useful when combined with mem::forget to hold a lock without the need to maintain a MutexGuard object alive, for example when dealing with FFI.

Safety

You must ensure that there are no data races when dereferencing the returned pointer, for example if the current thread logically owns a MutexGuard but that guard has been discarded using mem::forget.

pub fn lock_arc(self: &Arc<Mutex<R, T>>) -> ArcMutexGuard<R, T>

Acquires a lock through an Arc.

This method is similar to the lock method; however, it requires the Mutex to be inside of an Arc and the resulting mutex guard has no lifetime requirements.

pub fn try_lock_arc(self: &Arc<Mutex<R, T>>) -> Option<ArcMutexGuard<R, T>>

Attempts to acquire a lock through an Arc.

This method is similar to the try_lock method; however, it requires the Mutex to be inside of an Arc and the resulting mutex guard has no lifetime requirements.

pub unsafe fn force_unlock_fair(&self)

Forcibly unlocks the mutex using a fair unlock protocol.

This is useful when combined with mem::forget to hold a lock without the need to maintain a MutexGuard object alive, for example when dealing with FFI.

Safety

This method must only be called if the current thread logically owns a MutexGuard but that guard has been discarded using mem::forget. Behavior is undefined if a mutex is unlocked when not locked.

pub fn try_lock_for( &self, timeout: <R as RawMutexTimed>::Duration, ) -> Option<MutexGuard<'_, R, T>>

Attempts to acquire this lock until a timeout is reached.

If the lock could not be acquired before the timeout expired, then None is returned. Otherwise, an RAII guard is returned. The lock will be unlocked when the guard is dropped.

pub fn try_lock_until( &self, timeout: <R as RawMutexTimed>::Instant, ) -> Option<MutexGuard<'_, R, T>>

Attempts to acquire this lock until a timeout is reached.

If the lock could not be acquired before the timeout expired, then None is returned. Otherwise, an RAII guard is returned. The lock will be unlocked when the guard is dropped.

pub fn try_lock_arc_for( self: &Arc<Mutex<R, T>>, timeout: <R as RawMutexTimed>::Duration, ) -> Option<ArcMutexGuard<R, T>>

Attempts to acquire this lock through an Arc until a timeout is reached.

This method is similar to the try_lock_for method; however, it requires the Mutex to be inside of an Arc and the resulting mutex guard has no lifetime requirements.

pub fn try_lock_arc_until( self: &Arc<Mutex<R, T>>, timeout: <R as RawMutexTimed>::Instant, ) -> Option<ArcMutexGuard<R, T>>

Attempts to acquire this lock through an Arc until a timeout is reached.

This method is similar to the try_lock_until method; however, it requires the Mutex to be inside of an Arc and the resulting mutex guard has no lifetime requirements.