pub struct TlbRequest {
pub space_id: AddressSpaceId,
pub epoch: VmEpoch,
pub targets: usize,
pub ranges: Vec<TlbRange, MAX_INLINE_TLB_RANGES>,
/* private fields */
}Expand description
A shootdown obligation. It is deliberately independent of the platform IPI implementation so a timeout cannot be mistaken for a completed flush.
Fields
space_id: AddressSpaceIdepoch: VmEpochtargets: usizeranges: Vec<TlbRange, MAX_INLINE_TLB_RANGES>Implementations
Sourceimpl TlbRequest
impl TlbRequest
pub fn new(space_id: AddressSpaceId, epoch: VmEpoch, targets: usize) -> Self
pub fn with_range(self, range: TlbRange) -> Self
Sourcepub fn try_with_range(self, range: TlbRange) -> Result<Self, MutationError>
pub fn try_with_range(self, range: TlbRange) -> Result<Self, MutationError>
Fallible variant used by prepare paths that must not turn metadata pressure into a panic.
pub const fn targets(&self) -> usize
pub const fn acknowledged_mask(&self) -> usize
pub fn acknowledge(&mut self, cpu: usize) -> bool
pub fn pending(&self) -> usize
pub fn is_complete(&self) -> bool