The core functionality of a monolithic kernel, including loading user programs and managing processes.
Modules
Macros
- debug
- Dynamic debug macro. When
dynamic_debugfeature is enabled, uses per-callsite static key for runtime control via/proc/dynamic_debug/control. Otherwise falls back tolog::debug!. - debug_
fn - Dynamic debug macro. When
dynamic_debugfeature is enabled, uses per-callsite static key for runtime control via/proc/dynamic_debug/control, and also prints the function name of the callsite. Otherwise falls back tolog::debug!.
Structs
Enums
- DmaOperation
- The operation that gives a DMA-domain failure its Linux ABI meaning.
- Starry
Error - Errors owned by the Starry kernel below the Linux syscall ABI boundary.
Type Aliases
- Starry
Result - A result returned by Starry-owned kernel operations.