Crate starry_kernel

Crate starry_kernel 

The core functionality of a monolithic kernel, including loading user programs and managing processes.

Modules

dyn_debug
entry

Macros

debug
Dynamic debug macro. When dynamic_debug feature is enabled, uses per-callsite static key for runtime control via /proc/dynamic_debug/control. Otherwise falls back to log::debug!.
debug_fn
Dynamic debug macro. When dynamic_debug feature is enabled, uses per-callsite static key for runtime control via /proc/dynamic_debug/control, and also prints the function name of the callsite. Otherwise falls back to log::debug!.