The core functionality of a monolithic kernel, including loading user programs and managing processes.
Modules
Macros
- debug
- Dynamic debug macro. When
dynamic_debugfeature is enabled, uses per-callsite static key for runtime control via/proc/dynamic_debug/control. Otherwise falls back tolog::debug!. - debug_
fn - Dynamic debug macro. When
dynamic_debugfeature is enabled, uses per-callsite static key for runtime control via/proc/dynamic_debug/control, and also prints the function name of the callsite. Otherwise falls back tolog::debug!.