macro_rules! debug_fn {
($fmt:literal $(, $arg:expr)* $(,)?) => { ... };
}Expand description
Dynamic debug macro. When dynamic_debug feature is enabled,
uses per-callsite static key for runtime control via /proc/dynamic_debug/control, and also prints the function name of the callsite.
Otherwise falls back to log::debug!.
Note
This macro depends on the derive macro #[ddebug::named] to work, which will set the function name for the debug site.