pub type InstalledAddressSpace = InstalledPageTableRoot;Expand description
Name used by scheduler code that treats the root, identity, tag and epoch as one installed context.
Aliased Type
pub struct InstalledAddressSpace { /* private fields */ }pub type InstalledAddressSpace = InstalledPageTableRoot;Name used by scheduler code that treats the root, identity, tag and epoch as one installed context.
pub struct InstalledAddressSpace { /* private fields */ }